from dicgram.cliente import Bot

copy = 'Copyright (c) 2022 Marcelo <https://github.com/marcellobatiista>'
version = '2.0.8'
autor = 'Marcelo Batista'
email = 'batista.marcelo34@gmail.com'

Bot.copyright = copy
Bot.version = version
